==> idm_keras-0.0.2-py3-none-any.whl: idm_keras/build_dataset_nl.py <==
#!/usr/bin/python3

import sys
import pdb
import os
import json
from collections import defaultdict

if len(sys.argv) < 3:
    print( "Usage: {0} input_file root_real_path root_flow_path ".format( sys.argv[0] ) )
    sys.exit()

dryrun = False
input_file = sys.argv[1]
root_real_path = sys.argv[2]
root_flow_path = sys.argv[3]
print( "input file: " + input_file )
print( "root real path: " + root_real_path )
print( "root flow path: " + root_flow_path )

if not os.path.exists( root_flow_path ):
    os.mkdir( root_flow_path )

data = defaultdict(list)
#for label in [1, 2, 3]:
for label in [0, 1, 2]:
    new_dir = os.path.join( root_flow_path, str(label) )
    if not os.path.exists( new_dir ):
        os.mkdir( new_dir )
    data[label] = []

firstline = True
with open( input_file ) as f:
    for line in f:
        if firstline:
            firstline = False
            continue
        #print( line )
        filename = line.split(',')[0]
        try:
            label = int(line.split(',')[2]) # this line is for nightlights
        except:
            print( "Doesn't look like there are labels in this source file. Going to just put everything in '0'" )
            label = 0
        #label = int(line.split(',')[-1]) # this line is for dhs data
        #label = 0 # this is for not-categorized data
        if len( data[label] ) < 1000000: # at one point I wanted an upper limit
            data[label].append( filename )

with open( "/var/tmp/data_by_label.json", "w" ) as datafile:
    json.dump( data, datafile, sort_keys=True, indent=4 ) 
print( "Wrote label mapping to: " + "/var/tmp/data_by_label.json" )

duplicate_handling_mode = 2
for label in data:
    for filename in data[label]:
        come_back_here = os.getcwd()
        os.chdir( os.path.join( root_flow_path, str(label) ) )
        from_filename = os.path.basename(filename).strip()
        to_filename = os.path.join( root_real_path, str(filename) ).strip()
        if dryrun:
            print( "Creating symlink from {0} to {1}.".format( from_filename, to_filename ) )
        else:
            try:
                os.symlink( to_filename, from_filename )
                sys.stdout.write( "." )
            except Exception as ex:
                # 3 possible approaches:
                # 0) Error and die
                # 1) Continue w/o duplicate or dying
                # 2) Deliberately create duplicate
                if duplicate_handling_mode == 0:
                    print( "Error: Symlink already exists and that shouldn't happen." )
                    print( str( ex ) )
                    sys.exit()
                elif duplicate_handling_mode == 1:
                    pass
                else: # duplicate_handling_mode == 2:
                    # This is a solution to allow upsampling with symlinks.
                    print( str( ex ) )
                    N = 1
                    new_name = from_filename.strip(".png") + "_" + str(N) + ".png"
                    while os.path.exists( new_name ):
                        N += 1
                        new_name = from_filename.strip(".png") + "_" + str(N) + ".png"
                    print( "Creating duplicate with unique name...{}".format(new_name) )
                    os.symlink( to_filename, new_name )
                    sys.stdout.write( "." )
        os.chdir( come_back_here )

# create symlinks to these files under the appropriate label subdirectory

==> idm_keras-0.0.5-py3-none-any.whl: idm_keras/build_dataset_nl.py <==
#!/usr/bin/python3

import sys
import pdb
import os
import json
from collections import defaultdict

if len(sys.argv) < 3:
    print( "Usage: {0} input_file root_real_path root_flow_path ".format( sys.argv[0] ) )
    print( "input_file = csv file with image filenames in column 0 and classification labels in column 2; 
            root_real_path = existing path to actual imagery data;
            root_flow_path = name of directory to be created that will be input to Keras." )
    sys.exit()

dryrun = False
input_file = sys.argv[1]
root_real_path = sys.argv[2]
root_flow_path = sys.argv[3]
print( input_file )
if not os.path.exists( root_flow_path ):
    os.mkdir( root_flow_path )

data = defaultdict(list)
for label in [0, 1, 2]:
    new_dir = os.path.join( root_flow_path, str(label) )
    if not os.path.exists( new_dir ):
        os.mkdir( new_dir )
    data[label] = []

firstline = True
with open( input_file ) as f:
    for line in f:
        if firstline:
            firstline = False
            continue
        #print( line )
        filename = line.split(',')[0]
        try:
            label = int(line.split(',')[2]) # this line is for nightlights
        except:
            print( "Doesn't look like there are labels in this source file. Going to just put everything in '0'" )
            label = 0
        #label = int(line.split(',')[-1]) # this line is for dhs data
        #label = 0 # this is for not-categorized data
        if len( data[label] ) < 1000000: # at one point I wanted an upper limit
            data[label].append( filename )

with open( "data_by_label.json", "w" ) as datafile:
    json.dump( data, datafile, sort_keys=True, indent=4 ) 
print( "Wrote label mapping to: " + "data_by_label.json" )

for label in data:
    for filename in data[label]:
        come_back_here = os.getcwd()
        os.chdir( os.path.join( root_flow_path, str(label) ) )
        from_filename = filename.strip()
        to_filename = os.path.join( root_real_path, str(filename) ).strip()
        if dryrun:
            print( "Creating symlink from {0} to {1}.".format( from_filename, to_filename ) )
        else:
            try:
                os.symlink( to_filename, from_filename )
                sys.stdout.write( "." )
            except Exception as ex:
                # This is a solution to allow upsampling with symlinks.
                print( str( ex ) )
                N = 1
                new_name = from_filename.strip(".png") + "_" + str(N) + ".png"
                while os.path.exists( new_name ):
                    N += 1
                    new_name = from_filename.strip(".png") + "_" + str(N) + ".png"
                print( "Creating duplicate with unique name...{}".format(new_name) )
                os.symlink( to_filename, new_name )
                sys.stdout.write( "." )
        os.chdir( come_back_here )

# create symlinks to these files under the appropriate label subdirectory
